@@ -8,6 +8,7 @@ from rapconector.utils import parse_or_raise
 
 class Document:
     '''Representação de um documento no Conector.'''
+
     def __init__(self, client, json):
         # API client, for future requests.
         self._client = client
@@ -73,18 +74,20 @@ class Document:
 
         :param document_type: Código do tipo do documento.
         :type document_type: :class:`DocumentType <DocumentType>` ou
-            :class:`ExternalDocumentType <ExternalDocumentType>`, optional
+            :class:`ExternalDocumentType <ExternalDocumentType>`
 
         :param document_data: Dados do documento (string JSON).
         :type document_data: str, optional
 
         :param document_file: Arquivo(s) do documento, onde um arquivo é uma
-            tupla ``(name (str), file (IOBase), mime_type (str))``
+            tupla ``(name (str), file (IOBase), mime_type (str))``. Opcional
+            somente caso ``revocation_data`` seja informado.
         :type document_file: tuple or list(tuple), optional
 
         :param revocation_data: Dados para a revogação do documento. Vale notar
             que em casos de atualização dos dados de revogação do documento, o
             processamento não é reiniciado e o estado de revogação se mantém.
+            Opcional somente caso ``document_file`` seja informado.
         :type revocation_data: DocumentRevocationData, optional.
 
         :param update_description: Mensagem de atualização.
@@ -93,18 +96,17 @@ class Document:
         :return: O identificador do documento atualizado.
         :rtype: int
         '''
-        fields = {
-            'documentType':
-            str(document_type) if document_type is not None else None,
-            'documentData':
-            document_data,
-            'revocationData':
-            revocation_data.as_json() if revocation_data is not None else None,
-            'updateDescription':
-            update_description
-        }
+        fields = {}
+        if document_type:
+            fields['documentType'] = str(document_type)
+        if document_data:
+            fields['documentData'] = document_data
+        if update_description:
+            fields['updateDescription'] = update_description
         if document_file:
             fields['documentFile'] = document_file
+        if revocation_data:
+            fields['revocationData'] = revocation_data.as_json()
 
         encoder = MultipartEncoder(fields=fields)
 
@@ -378,6 +380,7 @@ class DocumentAuthenticityResult:
     ``valid`` os outros campos podem ou não estar preenchidos, de acordo com a
     validade do documento.
     '''
+
     def __init__(self, json):
         #: Identificador da blockchain em que o documento está registrado.
         self.dlt_id = json.get('dlt_id')
@@ -433,6 +436,7 @@ class DocumentAuthenticityResult:
 
 class DocumentGroup:
     '''Representação de um grupo de documentos.'''
+
     def __init__(self, json):
         #: String de identificação do grupo.
         self.group_id = json.get('groupId')
@@ -469,6 +473,7 @@ class DocumentProcessingStep:
 
 class DocumentSignature:
     '''Representação de uma assinatura em um documento.'''
+
     def __init__(self, json):
         #: Nome do assinante.
         self.signer = json.get('signer')
@@ -524,6 +529,7 @@ class DocumentSignatureState:
 
 class DocumentState:
     '''Representação do estado atual do processamento de um documento.'''
+
     def __init__(self, current_state, description, additional_info,
                  signatures):
         #: Código de estado atual do documento. Ver
@@ -550,6 +556,7 @@ class DocumentState:
 
 class DocumentStateChange:
     '''Representação do histórico de processamento de um documento.'''
+
     def __init__(self, previous_state, current_state, description, timestamp,
                  additional_info):
         #: Código de estado anterior do documento. Ver
@@ -696,6 +703,7 @@ class DocumentRevocationReason:
 
 class DocumentRevocationData:
     '''Representa dados sobre a revogação de um documento.'''
+
     def __init__(self, reason, notes=""):
         '''
         Inicializa um objeto contendo dados sobre a revogação de um documento.
@@ -711,4 +719,4 @@ class DocumentRevocationData:
 
     def as_json(self):
         '''Serializa os dados sobre a revogação, em formato JSON.'''
-        json_dumps({"reason": self.reason, "notes": self.notes})
+        return json_dumps({"reason": self.reason, "notes": self.notes})
